@@ -2,10 +2,9 @@
 # --------------------------- Import libraries and functions --------------------------
 from typing import Optional, Union
 
-import numpy as np
 import pandas as pd
 
-from pycvcqv.dataframe import processor_cv
+from pycvcqv.dataframe import cv_dataframe
 from pycvcqv.formulas import _cv
 from pycvcqv.is_numeric import is_numeric
 from pycvcqv.types import ArrayFloat, ArrayInt, ListFloat, ListInt, TupleFloat, TupleInt
@@ -58,10 +57,6 @@ def coefficient_of_variation(
         Union[float, pd.DataFrame]: the coefficient(s) of variation i.e.,
             sd(x)/mean(x).
 
-    Raises:
-        TypeError: If data is not pandas.core.series.Series, numpy.ndarray, list,
-            or tuple!
-
     Examples:
         .. code:: python
 
@@ -78,7 +73,7 @@ def coefficient_of_variation(
     """
     # ----------------------------------- DataFrame  ----------------------------------
     if isinstance(data, pd.DataFrame):
-        result = processor_cv(
+        result = cv_dataframe(
             data=data,
             num_threads=num_threads,
             ddof=ddof,
@@ -88,11 +83,6 @@ def coefficient_of_variation(
             multiplier=multiplier,
         )
     # --------------------------------- non DataFrame  --------------------------------
-    elif isinstance(data, (list, np.ndarray, pd.Series, tuple)):
-        result = float(_cv(data, ddof, skipna, ndigits, correction, multiplier))
     else:
-        raise TypeError(
-            """data must be \
-pandas.core.series.Series, numpy.ndarray, list, or tuple!"""
-        )
+        result = float(_cv(data, ddof, skipna, ndigits, correction, multiplier))
     return result
